@@ -1,4 +1,4 @@
-__version__ = "0.0.17"
+__version__ = "0.0.19"
 
 from .brokers import (
     Broker,
@@ -18,6 +18,8 @@ from .decorators import (
     EnrouteBuilder,
     EnrouteDecorator,
     EnrouteDecoratorKind,
+    PeriodicEnrouteDecorator,
+    PeriodicEventEnrouteDecorator,
     RestCommandEnrouteDecorator,
     RestEnrouteDecorator,
     RestQueryEnrouteDecorator,
@@ -58,6 +60,7 @@ from .handlers import (
     HandlerSetup,
 )
 from .messages import (
+    USER_CONTEXT_VAR,
     Request,
     Response,
     ResponseException,
@@ -70,6 +73,14 @@ from .rest import (
     RestResponseException,
     RestService,
 )
+from .scheduling import (
+    PeriodicTask,
+    PeriodicTaskScheduler,
+    PeriodicTaskSchedulerService,
+    ScheduledRequest,
+    ScheduledRequestContent,
+    ScheduledResponseException,
+)
 from .snapshots import (
     SnapshotService,
 )
