@@ -1,10 +1,3 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
 from minos.common import (
     MinosException,
 )
@@ -18,6 +11,10 @@ class MinosDiscoveryConnectorException(MinosNetworkException):
     """Exception to be raised when there is a failure while communicating with the discovery."""
 
 
+class MinosInvalidDiscoveryClient(MinosNetworkException):
+    """Exception raised when the configured Discovery Client does not implement de DiscoveryClient interface"""
+
+
 class MinosHandlerException(MinosNetworkException):
     """Base handler exception."""
 
